@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.18 1999/11/22 18:26:24 bazsi Exp $ */
+ * $Id: io.c,v 1.19 2000/02/04 19:02:04 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -345,7 +345,7 @@ static int do_read(struct abstract_read **r, UINT32 length, UINT8 *buffer)
     }
 }
 
-static int do_recv(struct abstract_read **r, UINT32 length, UINT8 *buffer, abstract_addr *addr, socklen_t *addrlen)
+static int do_recv(struct abstract_read **r, UINT32 length, UINT8 *buffer, abstract_addr *addr, int *addrlen)
 {
 	CAST(fd_read, closure, *r);
 
@@ -355,7 +355,7 @@ static int do_recv(struct abstract_read **r, UINT32 length, UINT8 *buffer, abstr
 	}
 
 	for (;;) {
-		int res = recvfrom(closure->fd, buffer, length, 0, (struct sockaddr *) addr, addrlen);
+		int res = recvfrom(closure->fd, buffer, length, 0, (struct sockaddr *) addr, (socklen_t *) addrlen);
 		if (!res) {
 
 			debug("Read EOF on fd %i.\n", closure->fd);
@@ -986,7 +986,7 @@ struct address_info *sockaddr2address_info(size_t addr_len,
 	}
 	case AF_UNIX: {
 		struct sockaddr_un *un = (struct sockaddr_un *) addr;
-		return &make_unix_address_c(un->sun_path)->super;
+		return &make_unix_address(c_format("%z", un->sun_path))->super;
 	}
 #if 0
 	case AF_INETv6:
